==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/actions/WifiAction.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from "@angular/core";
import {
  ConnectionHandler
} from "../ConnectionHandler";
import type {
  RepetierState,
  WifiState
} from "../state/RepetierState";
import {
  createAction, props, Store
} from "@ngrx/store";
import {take} from "rxjs/operators";
import {Ethernet} from "../state/RepetierState";

export const WifiUpdateStateAction = createAction("WIFI_UPDATE_STATE", props<WifiState>());
export const WifiSetEthernetAction = createAction("WIFI_SET_ETHERNET", props<WifiState>());

@Injectable()
export class WifiAction {

  constructor(private redux: Store<RepetierState>, private connectionHandler: ConnectionHandler) {
  }

  private updatingList = false;
  private updatingRouterList = false;

  setWifiList(list: WifiState): void {
    this.redux.dispatch(WifiUpdateStateAction(list));
  }

  updateRouterList(): void {
    if (this.updatingList) {
      return;
    }
    if (this.connectionHandler.connectionState.getValue() === false) {
      return;
    }
    this.updatingList = true;
    this.connectionHandler.send("wifiScanRouter").then(
      (wifiData) => {
        this.redux.dispatch(WifiUpdateStateAction(wifiData));
        this.updatingList = false;
      }, () => {
        this.updatingList = false;
      }
    );
  }

  refreshRouterList(): void {
    if (this.updatingRouterList) {
      return;
    }
    if (this.connectionHandler.connectionState.getValue() === false) {
      return;
    }
    this.updatingRouterList = true;
    this.connectionHandler.send("wifiRefreshRouter").then(
      (r) => {
        console.log('wifiRefreshRouter', r);
        this.redux.dispatch(WifiUpdateStateAction(r));
        this.updatingRouterList = false;
      }, () => {
        this.updatingRouterList = false;
      }
    );
  }

  setEthernet(options) {
    let eth: Ethernet;
    this.redux.select("wifi").pipe(take(1)).subscribe((wifi: WifiState) => {
      eth = wifi.ethernet;
    });
    const all = Object.assign({}, eth, options);
    this.redux.dispatch(WifiSetEthernetAction(all));
    this.connectionHandler.send('ethernetSet', all);
  }

  setHostname(hn: string) {
    this.connectionHandler.send("wifiSetHostname", {hostname: hn});
  }

  setApSSID(ssid: string) {
    this.connectionHandler.send("wifiSetAPSSID", {ssid: ssid});
  }

  setRegion(cntry: string) {
    this.connectionHandler.send("wifiSetCountry", {country: cntry});
  }

  setApMode(mode: number) {
    this.connectionHandler.send("wifiSetAPMode", {apMode: mode});
  }

  setApChannel(channel: number) {
    this.connectionHandler.send("wifiSetAPChannel", {channel: channel});
  }

  setApPassword(pw: string) {
    this.connectionHandler.send("wifiSetAPPassword", {password: pw});
  }

  connect(uuid: string): Promise<any> {
    return this.connectionHandler.send("wifiConnect", {uuid: uuid});
  }

  connectPassword(ssid: string, pw: string): Promise<any> {
    return this.connectionHandler.send("wifiConnectPW", {ssid: ssid, password: pw});
  }

  activateAP(uuid: string) {
    this.connectionHandler.send("wifiActivateAP", {});
  }

}

==> RSTouchscreenNG-1.4.1.zip: RSTouchscreenNG/projects/binding/src/lib/actions/WifiAction.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from "@angular/core";
import {
  ConnectionHandler
} from "../ConnectionHandler";
import type {
  RepetierState,
  WifiState
} from "../state/RepetierState";
import {
  createAction, props, Store
} from "@ngrx/store";
import {take} from "rxjs/operators";
import {Ethernet} from "../state/RepetierState";

export const WifiUpdateStateAction = createAction("WIFI_UPDATE_STATE", props<WifiState>());
export const WifiSetEthernetAction = createAction("WIFI_SET_ETHERNET", props<WifiState>());

@Injectable()
export class WifiAction {

  constructor(private redux: Store<RepetierState>, private connectionHandler: ConnectionHandler) {
  }

  private updatingList = false;
  private updatingRouterList = false;

  setWifiList(list: WifiState): void {
    this.redux.dispatch(WifiUpdateStateAction(list));
  }

  updateRouterList(): void {
    if (this.updatingList) {
      return;
    }
    if (this.connectionHandler.connectionState.getValue() === false) {
      return;
    }
    this.updatingList = true;
    this.connectionHandler.send("wifiScanRouter").then(
      (wifiData) => {
        this.redux.dispatch(WifiUpdateStateAction(wifiData));
        this.updatingList = false;
      }, () => {
        this.updatingList = false;
      }
    );
  }

  refreshRouterList(): void {
    if (this.updatingRouterList) {
      return;
    }
    if (this.connectionHandler.connectionState.getValue() === false) {
      return;
    }
    this.updatingRouterList = true;
    this.connectionHandler.send("wifiRefreshRouter").then(
      (r) => {
        // console.log('wifiRefreshRouter', r);
        this.redux.dispatch(WifiUpdateStateAction(r));
        this.updatingRouterList = false;
      }, () => {
        this.updatingRouterList = false;
      }
    );
  }

  setEthernet(options) {
    let eth: Ethernet;
    this.redux.select("wifi").pipe(take(1)).subscribe((wifi: WifiState) => {
      eth = wifi.ethernet;
    });
    const all = Object.assign({}, eth, options);
    this.redux.dispatch(WifiSetEthernetAction(all));
    this.connectionHandler.send('ethernetSet', all);
  }

  setHostname(hn: string) {
    this.connectionHandler.send("wifiSetHostname", {hostname: hn});
  }

  setApSSID(ssid: string) {
    this.connectionHandler.send("wifiSetAPSSID", {ssid: ssid});
  }

  setRegion(cntry: string) {
    this.connectionHandler.send("wifiSetCountry", {country: cntry});
  }

  setApMode(mode: number) {
    this.connectionHandler.send("wifiSetAPMode", {apMode: mode});
  }

  setApChannel(channel: number) {
    this.connectionHandler.send("wifiSetAPChannel", {channel: channel});
  }

  setApPassword(pw: string) {
    this.connectionHandler.send("wifiSetAPPassword", {password: pw});
  }

  connect(uuid: string): Promise<any> {
    return this.connectionHandler.send("wifiConnect", {uuid: uuid});
  }

  connectPassword(ssid: string, pw: string): Promise<any> {
    return this.connectionHandler.send("wifiConnectPW", {ssid: ssid, password: pw});
  }

  activateAP(uuid: string) {
    this.connectionHandler.send("wifiActivateAP", {});
  }

}
